summaryrefslogtreecommitdiff
path: root/src/pgm_sender.hpp
diff options
context:
space:
mode:
authorMartin Lucina <martin@lucina.net>2012-05-20 07:40:11 +0200
committerMartin Sustrik <sustrik@250bpm.com>2012-05-25 14:02:16 +0200
commita34ea4d80609395150742259fd8c9caa4409e961 (patch)
treeaa5c1793e7e5e276e4ded626adbe042e75740ff6 /src/pgm_sender.hpp
parent6b7089891bdb3a4c55b43d0854787c96fae3bf2b (diff)
Implement SP wire protocol
Implements the SP wire protocol, and infrastructure for legacy wire protocol support. Also added an XS_SERVICE_ID socket option to set the service id and renamed the XS_PROTOCOL option to XS_PATTERN_VERSION. The following pattern versions are supported: PAIR: v3 PUBSUB: v1 (legacy), v4 REQREP: v2 PIPELINE: v3 SURVEY: v2 Note that all existing pattern versions have been bumped by 1 to allow for use of legacy protocols (otherwise there would be no way to distinguish between e.g. PUBSUB v3 and PUBSUB v3 using SP). Signed-off-by: Martin Lucina <martin@lucina.net>
Diffstat (limited to 'src/pgm_sender.hpp')
-rw-r--r--src/pgm_sender.hpp15
1 files changed, 12 insertions, 3 deletions
diff --git a/src/pgm_sender.hpp b/src/pgm_sender.hpp
index 89f81bf..5a808b6 100644
--- a/src/pgm_sender.hpp
+++ b/src/pgm_sender.hpp
@@ -84,12 +84,21 @@ namespace xs
handle_t rdata_notify_handle;
handle_t pending_notify_handle;
// Output buffer from pgm_socket.
unsigned char *out_buffer;
-
- // Output buffer size.
size_t out_buffer_size;
+ // Size of header in each datagram.
+ size_t header_size;
+
+ // Encoder buffer and size, adjusted from output buffer by size of
+ // datagram header(s).
+ unsigned char *encode_buffer;
+ size_t encode_buffer_size;
+
+ // Position of offset to first message in output buffer.
+ unsigned char *offset_p;
+
// Number of bytes in the buffer to be written to the socket.
// If zero, there are no data to be sent.
size_t write_size;
@@ -84,12 +84,21 @@ namespace xs
handle_t rdata_notify_handle;
handle_t pending_notify_handle;
- // Output buffer from pgm_socket.
+ // Output buffer and size for pgm_socket.
unsigned char *out_buffer;